"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const fs = require("fs");
const path = require("path");
class EnvList extends command_1.Command {
    async run() {
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        this.log();
        const homedir = (process.platform === 'win32') ? process.env.HOMEPATH : process.env.HOME;
        const projectPath = process.cwd().split('/');
        const projectName = projectPath[projectPath.length - 1];
        const all = fs.readdirSync(path.join(homedir, '.powerbot-cli', 'environments'));
        let projectEnvs = all.filter((env) => {
            const exp = new RegExp(projectName, 'gi');
            return exp.test(env);
        }).map((env) => {
            return env.replace(`${projectName}-`, '').replace('.json', '');
        });
        if (!projectEnvs.length) {
            this.log(chalk_1.default.yellow(`No environments configured for project '${projectName}'\n`));
            return process.exit(0);
        }
        this.log(chalk_1.default.cyan(`Following environments are configured for project '${projectName}':`));
        for (const env of projectEnvs) {
            this.log(chalk_1.default.cyan(`  * ${env}`));
        }
        this.log();
        process.exit(0);
    }
}
EnvList.description = 'Lists environments configured for current project directory.';
exports.default = EnvList;
