"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const keytar = require("keytar");
const readline = require("readline");
const fs = require("fs");
const path = require("path");
const { promisify } = require('util');
// @ts-ignore
readline.Interface.prototype.question[promisify.custom] = function (prompt) {
    return new Promise(resolve => readline.Interface.prototype.question.call(this, prompt, resolve));
};
// @ts-ignore
readline.Interface.prototype.questionAsync = promisify(readline.Interface.prototype.question);
const rl = readline.createInterface(process.stdin, process.stdout);
// @ts-ignore
rl._writeToOutput = function _writeToOutput(stringToWrite) {
    // @ts-ignore
    if (rl.stdoutMuted)
        // @ts-ignore
        rl.output.write("\x1B[2K\x1B[200D" + rl.query + "[" + ((rl.line.length % 2 == 1) ? "=-" : "-=") + "]");
    else
        // @ts-ignore
        rl.output.write(stringToWrite);
};
class EnvCreate extends command_1.Command {
    async run() {
        const { args } = this.parse(EnvCreate);
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        const projectPath = process.cwd().split('/');
        const projectName = projectPath[projectPath.length - 1];
        const envName = args.name;
        this.log();
        if (!args.name) {
            this.log(chalk_1.default.red('You need to provide name of environment.\n'));
            process.exit(0);
        }
        this.log(chalk_1.default.cyan('You need to provide connection credentials to desired database. All sensitive data will be stored in your system keychain.\n'));
        let db = {
            host: '',
            user: '',
            password: '',
            name: ''
        };
        try {
            // @ts-ignore
            db.host = await rl.questionAsync(chalk_1.default.cyan('Database host: '));
            // @ts-ignore
            db.user = await rl.questionAsync(chalk_1.default.cyan('Database user: '));
            // @ts-ignore
            db.name = await rl.questionAsync(chalk_1.default.cyan('Database name: '));
            // @ts-ignore
            rl.query = chalk_1.default.cyan('Database password: ');
            // @ts-ignore
            rl.stdoutMuted = true;
            // @ts-ignore
            db.password = await rl.questionAsync(chalk_1.default.cyan('Database password: '));
            // @ts-ignore
            rl.stdoutMuted = false;
            this.log('\n');
            const serviceName = `${projectName}-${envName}`;
            const storedForProject = await keytar.findCredentials(`${serviceName}-db`);
            for (let row of storedForProject) {
                await keytar.deletePassword(`${serviceName}-db`, row.account);
            }
            this.log(chalk_1.default.cyan(`Saving access data for ${serviceName.replace('-', ' - ')}...`));
            keytar.setPassword(serviceName + '-db', db.user, db.password);
            this.log(chalk_1.default.cyan('Saved sensitive data in system keychain.'));
            delete db.user;
            delete db.password;
            const homedir = (process.platform === 'win32') ? process.env.HOMEPATH : process.env.HOME;
            if (!fs.existsSync(path.join(homedir, '.powerbot-cli')))
                fs.mkdirSync(path.join(homedir, '.powerbot-cli'));
            if (!fs.existsSync(path.join(homedir, '.powerbot-cli', 'environments')))
                fs.mkdirSync(path.join(homedir, '.powerbot-cli', 'environments'));
            fs.writeFileSync(path.join(homedir, '.powerbot-cli', 'environments', `${serviceName}.json`), JSON.stringify(db));
            this.log(chalk_1.default.cyan('Saved less sensitive data to env file.'));
            this.log(chalk_1.default.green('\nDone! Environment is now ready to use.\n'));
            process.exit(0);
        }
        catch (e) {
            throw e;
        }
    }
}
EnvCreate.description = `Manages environments (database connection params) used for sync module.`;
EnvCreate.args = [{ name: 'name' }];
exports.default = EnvCreate;
