"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const keytar = require("keytar");
const fs = require("fs");
const path = require("path");
class EnvRemove extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(EnvRemove);
        this.log();
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        if (!args.name)
            this.log(chalk_1.default.red('You need to provide name of environment you want to remove.'));
        const projectPath = process.cwd().split('/');
        const projectName = projectPath[projectPath.length - 1];
        const envName = args.name;
        const serviceName = `${projectName}-${envName}`;
        const homedir = (process.platform === 'win32') ? process.env.HOMEPATH : process.env.HOME;
        try {
            if (!fs.existsSync(path.join(homedir, '.powerbot-cli', 'environments', `${serviceName}.json`))) {
                this.log(chalk_1.default.red(`No '${envName}' environment configured for project '${projectName}'\n`));
                return process.exit(0);
            }
            const storedForProject = await keytar.findCredentials(`${serviceName}-db`);
            for (let row of storedForProject) {
                await keytar.deletePassword(`${serviceName}-db`, row.account);
            }
            this.log(chalk_1.default.cyan('Removed from system keystore.'));
            fs.unlinkSync(path.join(homedir, '.powerbot-cli', 'environments', `${serviceName}.json`));
            this.log(chalk_1.default.cyan('Removed environment file.'));
            this.log(chalk_1.default.green('\nDone. All environment data has been removed.\n'));
            process.exit(0);
        }
        catch (e) {
            throw e;
        }
    }
}
EnvRemove.description = 'Removes selected environment data from system.';
EnvRemove.args = [{ name: 'name' }];
exports.default = EnvRemove;
