"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const child = require("child_process");
const os = require("os");
const fs = require("fs");
class Init extends command_1.default {
    async run() {
        const { args, flags } = this.parse(Init);
        this.log();
        if (!args.name) {
            return this.log(chalk_1.default.red('You need to specify name for new project. Run `powerbot help init` for details.\n'));
        }
        if (!args.version) {
            return this.log(chalk_1.default.red('You need to specify version of Powerbot CMS. Run `powerbot help init` for details.\n'));
        }
        this.log(chalk_1.default.cyan(`Creating directory '${args.name}'...`));
        fs.mkdirSync(`./${args.name}`);
        this.log(chalk_1.default.cyan('Running npm init...'));
        child.execSync(`cd ${args.name} && npm init --loglevel error -y > ${Init.nullDir}`, {
            stdio: 'inherit'
        });
        this.log(chalk_1.default.cyan(`Installing nodemon...`));
        child.execSync(`${Init.npm} install nodemon --save-dev --loglevel error > ${Init.nullDir}`, {
            stdio: 'inherit',
            cwd: `./${args.name}`
        });
        this.log(chalk_1.default.cyan(`Installing Powerbot CMS ${args.version} in '${args.name}' directory...`));
        child.execSync(`${Init.npm} install maxtomczyk/powerbot-cms#${args.version} --save --loglevel error > ${Init.nullDir}`, {
            stdio: 'inherit',
            cwd: `./${args.name}`
        });
        this.log(chalk_1.default.green(`\nProject initialized successfully. Now you need to configure your database connection in config.js file and then run 'powerbot setup' inside project directory.\n`));
        process.exit(0);
    }
}
Init.description = `Creates directory and initializes Powerbot CMS inside.
As version you can use any release available on https://github.com/maxtomczyk/powerbot-cms/releases
`;
Init.flags = {};
Init.args = [{ name: 'name' }, { name: 'version' }];
Init.aliases = ['create'];
Init.npm = (os.platform() === 'win32') ? 'npm.cmd' : 'npm';
Init.nullDir = (os.platform() === 'win32') ? 'nul' : '/dev/null';
exports.default = Init;
