"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const fs = require("fs");
class LanguageAdd extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(LanguageAdd);
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        this.log();
        const config = eval(fs.readFileSync('./config/config.js', 'utf-8'));
        const knex = require('knex')({
            client: 'pg',
            useNullAsDefault: true,
            connection: process.env.DATABASE_URL || {
                host: config.database.host,
                user: config.database.user,
                password: config.database.password,
                database: config.database.name
            }
        });
        try {
            const messages = await knex('messages');
            this.log(chalk_1.default.cyan(`Adding ${args.locale} to ${messages.length} messages and creating database transaction...`));
            await knex.transaction((trx) => {
                let queries = [];
                queries.push(trx('languages').insert(args).returning('*'));
                messages.map((message) => {
                    const anyLocaleData = JSON.parse(JSON.stringify(message.json[Object.keys(message.json)[0]]));
                    message.json[args.locale] = anyLocaleData;
                    if (message.json[args.locale].texts)
                        message.json[args.locale].texts = [`${message.name} default text in ${args.name} (${args.locale}) language.`];
                    queries.push(trx('messages').update('json', message.json).where('id', message.id));
                });
                console.log(chalk_1.default.cyan('Running transaction...'));
                return Promise.all(queries);
            });
            this.log(chalk_1.default.green('\nNew language is ready to use.\n'));
            process.exit(0);
        }
        catch (e) {
            throw e;
        }
    }
}
LanguageAdd.description = `Creates new language and messages variants for new locale.
  As locale you have to provide valid Facebook locale like en_US`;
LanguageAdd.flags = {};
LanguageAdd.args = [{ name: 'name' }, { name: 'locale' }];
exports.default = LanguageAdd;
