"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const fs = require("fs");
class LanguageChange extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(LanguageChange);
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        this.log();
        const config = eval(fs.readFileSync('./config/config.js', 'utf-8'));
        const knex = require('knex')({
            client: 'pg',
            useNullAsDefault: true,
            connection: process.env.DATABASE_URL || {
                host: config.database.host,
                user: config.database.user,
                password: config.database.password,
                database: config.database.name
            }
        });
        try {
            const lang = await knex('languages').where('name', args.nameOrLocaleToChange).orWhere('locale', args.nameOrLocaleToChange).first();
            if (!lang) {
                this.log(chalk_1.default.red('Passed language to change is not present in database.\n'));
                return process.exit(0);
            }
            const messages = await knex('messages');
            this.log(chalk_1.default.cyan(`Changing language to ${args.newLangLocale} in ${messages.length} messages and creating database transaction`));
            await knex.transaction((trx) => {
                let queries = [];
                queries.push(trx('languages').update({ name: args.newLangName, locale: args.newLangLocale }).where('id', lang.id));
                messages.map((message) => {
                    let localeToChangeData = JSON.parse(JSON.stringify(message.json[lang.locale]));
                    delete message.json[lang.locale];
                    message.json[args.newLangLocale] = localeToChangeData;
                    queries.push(trx('messages').update('json', message.json).where('id', message.id));
                });
                console.log(chalk_1.default.cyan('Running transaction...'));
                return Promise.all(queries);
            });
            this.log(chalk_1.default.green(`\nLanguage identified as ${args.nameOrLocaleToChange} has been changed to ${args.newLangName} (${args.newLangLocale})\n`));
            process.exit(0);
        }
        catch (e) {
            throw e;
        }
    }
}
LanguageChange.description = 'Changes languege into another.';
LanguageChange.flags = {};
LanguageChange.args = [{ name: 'nameOrLocaleToChange' }, { name: 'newLangName' }, { name: 'newLangLocale' }];
exports.default = LanguageChange;
