"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const fs = require("fs");
class LanguageDefault extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(LanguageDefault);
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        this.log();
        const config = eval(fs.readFileSync('./config/config.js', 'utf-8'));
        const knex = require('knex')({
            client: 'pg',
            useNullAsDefault: true,
            connection: process.env.DATABASE_URL || {
                host: config.database.host,
                user: config.database.user,
                password: config.database.password,
                database: config.database.name
            }
        });
        try {
            const lang = await knex('languages').where('name', args.langOrLocale).orWhere('locale', args.langOrLocale).first();
            if (!lang) {
                this.log(chalk_1.default.red('Passed language is not present in database.\n'));
                return process.exit(0);
            }
            await knex.transaction((trx) => {
                let queries = [];
                queries.push(trx('languages').update('default', false));
                queries.push(trx('languages').update('default', true).where('id', lang.id));
                console.log(chalk_1.default.cyan('Changing...'));
                return Promise.all(queries);
            });
            this.log(chalk_1.default.green(`\nChanged default language to ${lang.name} (${lang.locale})\n`));
            process.exit(0);
        }
        catch (e) {
            throw e;
        }
    }
}
LanguageDefault.description = 'Sets passed language or locale as default.';
LanguageDefault.args = [{ name: 'langOrLocale' }];
exports.default = LanguageDefault;
