"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const child = require("child_process");
const fs = require("fs");
const os = require("os");
const chalk_1 = require("chalk");
const init_1 = require("./init");
class Setup extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Setup);
        if (!fs.existsSync('./node_modules/powerbot-cms'))
            return this.log(chalk_1.default.red('\nNot in Powerbot CMS project.\n'));
        this.log();
        this.log(chalk_1.default.cyan('Running database creation...'));
        try {
            child.execSync(`node create_db.js > ${init_1.default.nullDir}`, {
                stdio: 'inherit',
                cwd: `./node_modules/powerbot-cms/scripts`
            });
            this.log(chalk_1.default.cyan('Running database initialize...'));
            child.execSync(`node init_db.js > ${init_1.default.nullDir}`, {
                stdio: 'inherit',
                cwd: `./node_modules/powerbot-cms/scripts`
            });
            this.log(chalk_1.default.cyan('Running database migrations...'));
            child.execSync(`knex migrate:latest > ${init_1.default.nullDir}`, {
                stdio: 'inherit',
                cwd: './node_modules/powerbot-cms'
            });
            this.log(chalk_1.default.green(`\nDatabase is ready!\n`));
            process.exit(0);
        }
        catch (e) {
            console.error(e);
            console.log(chalk_1.default.red('\nAn error occured during database setup. Details should be logged above.'));
        }
    }
}
Setup.description = 'Runs setup procedure like database import etc.';
Setup.flags = {};
Setup.nullDir = (os.platform() === 'win32') ? 'nul' : '/dev/null';
exports.default = Setup;
